package com.sundot.airport.item.service;

import com.sundot.airport.item.domain.HkPendingConfiscate;

import java.util.List;

public interface IHkPendingConfiscateService {

    List<HkPendingConfiscate> selectHkPendingConfiscateList(HkPendingConfiscate query);

    HkPendingConfiscate selectHkPendingConfiscateById(Long id);

    int insertHkPendingConfiscate(HkPendingConfiscate data);

    int updateHkPendingConfiscate(HkPendingConfiscate data);

    int deleteHkPendingConfiscateByIds(Long[] ids);

    String importData(List<HkPendingConfiscate> list);
}
